# Setup galaxy simulations

## Description
Reproduce the isolated disk galaxy simulations from Ploeckinger et al. (subm. 2023).

![Isolated disk galaxy](isolated_galaxy_examples.png "Stellar mass surface densities")


## Installation
The isolated galaxy simulations presented in Ploeckinger et al. (subm. 2023) use the [SWIFT](www.swiftsim.com) code (Schaller et al. [arXiv](https://arxiv.org/abs/2305.13380)). For reproducing these simulations install SWIFT following the information [here](https://swift.strw.leidenuniv.nl/docs/GettingStarted/index.html).

This repository contains the parameter file used in these simulations. Note, that in the future, the required parameters for the individual modules may change. After installing all [dependencies](https://swift.strw.leidenuniv.nl/docs/GettingStarted/compiling_code.html#dependencies) of SWIFT successfully, the SWIFT version used in Ploeckinger et al. (subm. 2023) can be setup and compiled with

```
git clone https://github.com/SWIFTSIM/SWIFT.git
cd SWIFT
git checkout v0.9.0-1182-g423e9dd8
./autogen.sh 
./configure --with-subgrid=EAGLE-XL --with-hydro=sphenix --with-kernel=quartic-spline --with-ext-potential=hernquist --with-tbbmalloc --disable-hand-vec --enable-ipo --enable-stand-alone-fof
make
```

If the code compiled successfully, the executables `swift` and `fof` are produced in the SWIFT folder. 

In possibly another directory, clone this reposity with

```
git clone git@gitlab.phaidra.org:softenedjeanscriteria/setup-galaxy-simulations.git
cd setup-galaxy-simulations
```

This repository contains the folder `fiducial_files` which requires the following changes:

- copy the `swift` executable into the folder `fiducial_files`
- check the job submission `submit.job` and resubmission scripts `resubmit.job`, they might need updating or replacing, depending on the job submission system. The strings `RUNNAME` and `TIMEINHOURS` are replaced by the appropriate values by the `setup.py` script later.



## Name
Choose a self-explaining name for your project.

## Description
Let people know what your project can do specifically. Provide context and add a link to any reference visitors might be unfamiliar with. A list of Features or a Background subsection can also be added here. If there are alternatives to your project, this is a good place to list differentiating factors.

## Badges
On some READMEs, you may see small images that convey metadata, such as whether or not all the tests are passing for the project. You can use Shields to add some to your README. Many services also have instructions for adding a badge.

## Visuals
Depending on what you are making, it can be a good idea to include screenshots or even a video (you'll frequently see GIFs rather than actual videos). Tools like ttygif can help, but check out Asciinema for a more sophisticated method.

## Installation
Within a particular ecosystem, there may be a common way of installing things, such as using Yarn, NuGet, or Homebrew. However, consider the possibility that whoever is reading your README is a novice and would like more guidance. Listing specific steps helps remove ambiguity and gets people to using your project as quickly as possible. If it only runs in a specific context like a particular programming language version or operating system or has dependencies that have to be installed manually, also add a Requirements subsection.

## Usage
Use examples liberally, and show the expected output if you can. It's helpful to have inline the smallest example of usage that you can demonstrate, while providing links to more sophisticated examples if they are too long to reasonably include in the README.

## Support
Tell people where they can go to for help. It can be any combination of an issue tracker, a chat room, an email address, etc.

## Roadmap
If you have ideas for releases in the future, it is a good idea to list them in the README.

## Contributing
State if you are open to contributions and what your requirements are for accepting them.

For people who want to make changes to your project, it's helpful to have some documentation on how to get started. Perhaps there is a script that they should run or some environment variables that they need to set. Make these steps explicit. These instructions could also be useful to your future self.

You can also document commands to lint the code or run tests. These steps help to ensure high code quality and reduce the likelihood that the changes inadvertently break something. Having instructions for running tests is especially helpful if it requires external setup, such as starting a Selenium server for testing in a browser.

## Authors and acknowledgment
Show your appreciation to those who have contributed to the project.

## License
For open source projects, say how it is licensed.

## Project status
If you have run out of energy or time for your project, put a note at the top of the README saying that development has slowed down or stopped completely. Someone may choose to fork your project or volunteer to step in as a maintainer or owner, allowing your project to keep going. You can also make an explicit request for maintainers.
